﻿// Import necessary .NET namespace that contain classes for drawing and forms
open System.Drawing
open System.Windows.Forms

// Function that creates & shows form with some drawing
let showForm () =
  // Create Windows Forms 'Form' object that represents a window
  // During construction, we also set its property 'TopMost' to 'true'
  //   and set the size of the drawing area to 600x400
  let form = new Form(TopMost = true, ClientSize = new Size(600, 400))
  
  // Alternative syntax for setting properties (mutating object) is:
  //    form.TopMost <- true
  //    form.ClientSize <- new Size(600, 400)
  
  // Show the window
  form.Show()

  // Register a function (lambda function) that will be called every 
  // time the window needs to redraw itself
  form.Paint.Add(fun pe ->
     
      // We can use 'pe.Graphics' object to draw on the form
      // Clear the entire form using white color
      pe.Graphics.Clear(Color.White)
      
      // Draw some lines on the form
      // You can use 'for' loop to draw steps of the function 
      for i in 0 .. 100 do
        // Using 'DrawLine' method to draw lines on the form
        pe.Graphics.DrawLine(Pens.DarkMagenta, i * 6, 100, (i + 1) * 6, 120)
    )
    


// TODO: Modify the function, so that it takes a function (float32 -> float32) 
//   as an argument and draws its graph. Optionally, you can add additional
//   parameters that specify the X and Y range.